=== modified file 'ivle/dispatch/__init__.py'
--- ivle/dispatch/__init__.py	2009-02-09 03:13:58 +0000
+++ ivle/dispatch/__init__.py	2009-02-09 04:50:20 +0000
@@ -62,6 +62,7 @@
     'ivle.webapp.console#Plugin',
     'ivle.webapp.security#Plugin',
     'ivle.webapp.media#Plugin',
+    'ivle.webapp.forum#Plugin',
 ] 
 
 def generate_route_mapper(view_plugins):

=== modified file 'ivle/dispatch/login.py'
--- ivle/dispatch/login.py	2009-02-03 23:49:34 +0000
+++ ivle/dispatch/login.py	2009-02-09 04:50:20 +0000
@@ -23,9 +23,16 @@
 import os
 import datetime
 
+try:
+    import mod_python.Cookie
+except ImportError:
+    # This needs to be importable from outside Apache.
+    pass
+
 import ivle.conf
-from ivle import (util, caps, forumutil)
+from ivle import (util, caps)
 from ivle.auth import authenticate, AuthError
+from ivle.webapp.base.plugins import CookiePlugin
 import ivle.database
 
 def login(req):
@@ -87,7 +94,16 @@
                     session.save()
                     user.last_login = datetime.datetime.now()
                     req.store.commit()
-                    req.add_cookie(forumutil.make_forum_cookie(user))
+
+                    # Create cookies for plugins that might request them.
+                    for plugin in req.plugin_index[CookiePlugin]:
+                        for cookie in plugin.cookies:
+                            # The function can be None if they just need to be
+                            # deleted at logout.
+                            if plugin.cookies[cookie] is not None:
+                                req.add_cookie(mod_python.Cookie.Cookie(cookie,
+                                      plugin.cookies[cookie](user), path='/'))
+
                     req.throw_redirect(req.uri)
 
     # Present the HTML login page

=== modified file 'ivle/dispatch/request.py'
--- ivle/dispatch/request.py	2009-02-09 03:13:58 +0000
+++ ivle/dispatch/request.py	2009-02-09 04:50:20 +0000
@@ -36,6 +36,7 @@
 import ivle.util
 import ivle.conf
 import ivle.database
+from ivle.webapp.base.plugins import CookiePlugin
 
 class Request:
     """An IVLE request object. This is presented to the IVLE apps as a way of
@@ -269,17 +270,17 @@
     def logout(self):
         """Log out the current user by destroying the session state.
         Then redirect to the top-level IVLE page."""
-        # List of cookies that IVLE uses (to be removed at logout)
-        ivle_cookies = ["ivleforumcookie", "clipboard"]
-        
         if hasattr(self, 'session'):
             self.session.invalidate()
             self.session.delete()
             # Invalidates all IVLE cookies
             all_cookies = mod_python.Cookie.get_cookies(self)
-            for cookie in all_cookies:
-                if cookie in ivle_cookies:
-                    self.add_cookie(mod_python.Cookie.Cookie(cookie,'',expires=1,path='/'))
+
+            # Create cookies for plugins that might request them.
+            for plugin in self.plugin_index[CookiePlugin]:
+                for cookie in plugin.cookies:
+                    self.add_cookie(mod_python.Cookie.Cookie(cookie, '',
+                                                    expires=1, path='/'))
         self.throw_redirect(ivle.util.make_path('')) 
 
 

=== removed file 'ivle/forumutil.py'
--- ivle/forumutil.py	2009-01-13 01:36:15 +0000
+++ ivle/forumutil.py	1970-01-01 00:00:00 +0000
@@ -1,48 +0,0 @@
-# IVLE
-# Copyright (C) 2007-2008 The University of Melbourne
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-# Module: forumutil
-# Author: David Coles
-# Date: 18/02/2008
-
-# Forum Utilities for communicating with the Forum
-
-import hashlib
-import time
-from mod_python import Cookie
-from urllib import quote
-import ivle.conf
-
-cookie_name = 'ivleforumcookie'
-
-def make_forum_cookie(login_details):
-    secret = ivle.conf.forum_secret
-
-    login = quote(login_details.login)
-    nick = quote(login_details.nick)
-    email = ''
-    if login_details.email != None:
-        email = quote(login_details.email)
-
-
-    role = quote(str(login_details.role))
-    
-    hashtext = login + nick + email + role + secret
-    hash = hashlib.md5(hashtext).hexdigest()
-    data = quote(login + ':' + nick + ':' + email + ':' + role + ':' + hash)
-
-    return Cookie.Cookie(cookie_name,data,path='/')

=== modified file 'ivle/webapp/base/plugins.py'
--- ivle/webapp/base/plugins.py	2009-02-09 00:56:51 +0000
+++ ivle/webapp/base/plugins.py	2009-02-09 04:50:20 +0000
@@ -41,3 +41,13 @@
     views. The canonical example of a plugin of this type is the Console plugin.
     """
     pass
+
+class CookiePlugin(BasePlugin):
+    """Marker class for plugins which provide cookies.
+
+    Cookie plugins provide a 'cookies' dict mapping names to generation
+    functions. The function should return the data to store in the cookie on
+    login. If the function is None, the cookie is not created on login, just
+    deleted on logout.
+    """
+    pass

=== modified file 'ivle/webapp/filesystem/browser/__init__.py'
--- ivle/webapp/filesystem/browser/__init__.py	2009-02-08 23:12:34 +0000
+++ ivle/webapp/filesystem/browser/__init__.py	2009-02-09 04:50:20 +0000
@@ -26,7 +26,7 @@
 take place in the FileService app (for handling Ajax requests).
 """
 
-from ivle.webapp.base.plugins import ViewPlugin
+from ivle.webapp.base.plugins import ViewPlugin, CookiePlugin
 from ivle.webapp.base.xhtml import XHTMLView
 
 import os.path
@@ -152,7 +152,7 @@
           ])
         ]
 
-class Plugin(ViewPlugin):
+class Plugin(ViewPlugin, CookiePlugin):
     """
     The Plugin class for the user plugin.
     """
@@ -165,4 +165,6 @@
         ('files/', BrowserView),
     ]
 
+    cookies = {'clipboard': None}
+
     media = 'media'

=== renamed directory 'www/apps/forum' => 'ivle/webapp/forum'
=== modified file 'ivle/webapp/forum/__init__.py'
--- www/apps/forum/__init__.py	2009-01-13 01:36:15 +0000
+++ ivle/webapp/forum/__init__.py	2009-02-09 04:50:20 +0000
@@ -1,5 +1,5 @@
-# IVLE
-# Copyright (C) 2007-2008 The University of Melbourne
+# IVLE - Informatics Virtual Learning Environment
+# Copyright (C) 2007-2009 The University of Melbourne
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,61 +15,81 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-# App: Forum
-# Author: David Coles
-# Date: 12/02/2008
-
-# This is an IVLE application.
-# A SMF forum application for IVLE.
+# Author: David Coles, Will Grant
 
 import os
+import re
+import time
+import hashlib
 import urlparse
-import re
-
-from ivle import util
-from ivle import interpret
-
-def handle(req):
-    """
-    Handler for the Forum application.
-    
-    This application implements a general purpose PHP CGI loader
-    """
-    
-    # Settings
-
-    forum_base = "php/phpBB3"
-
-    # Set request attributes
-
-    req.styles = ["media/forum/forum.css"]
-    
-    # Process URL for special directives
-    url = urlparse.urlparse(req.path)
-    hierarchical_part = url[2]
-
-    forum_page = "" # use the default forum page
-    framequery = "?"
-
-    board = re.match('board/(.*?)(/|$)',hierarchical_part)
-    if board:
-        framequery += 'f=' + board.group(1) + "&"
-        forum_page = "viewforum.php"
-
-    topic = re.search('topic/(.*?)(/|$)',hierarchical_part)
-    if topic:
-        framequery += 't=' + topic.group(1)
-        forum_page = "viewtopic.php"
-   
-    # If the tail of the forum url is empty or a known special request
-    # then wrap the page in the headers and footer and load the default or
-    # special page in the ivlebody frame
-    location = req.path
-    if board or topic:
-        location = forum_page + framequery
-    
-    frameurl = util.make_path(os.path.join(forum_base,location))
-    req.content_type = "text/html"
-    req.write_html_head_foot = True
-    req.write('<object class="fullscreen" type="text/html" data="%s">'%
-        (frameurl + framequery))
+from urllib import quote
+
+from ivle.webapp.base.xhtml import XHTMLView
+from ivle.webapp.base.plugins import ViewPlugin, CookiePlugin
+import ivle.util
+import ivle.conf
+
+class ForumView(XHTMLView):
+    appname = 'forum'
+
+    def __init__(self, req, path):
+        self.path = path
+
+    def populate(self, req, ctx):
+        self.plugin_styles[Plugin] = ['forum.css']
+
+        forum_base = "php/phpBB3"
+
+        # Process URL for special directives
+        url = urlparse.urlparse(self.path)
+        hierarchical_part = url[2]
+
+        forum_page = "" # use the default forum page
+        framequery = "?"
+
+        board = re.match('board/(.*?)(/|$)',hierarchical_part)
+        if board:
+            framequery += 'f=' + board.group(1) + "&"
+            forum_page = "viewforum.php"
+
+        topic = re.search('topic/(.*?)(/|$)',hierarchical_part)
+        if topic:
+            framequery += 't=' + topic.group(1)
+            forum_page = "viewtopic.php"
+
+        # If the tail of the forum url is empty or a known special request
+        # then wrap the page in the headers and footer and load the default or
+        # special page in the ivlebody frame
+        location = self.path
+        if board or topic:
+            location = forum_page + framequery
+
+        frameurl = ivle.util.make_path(os.path.join(forum_base,location))
+        ctx['url'] = frameurl + framequery
+
+def make_forum_cookie(user):
+    secret = ivle.conf.forum_secret
+
+    login = quote(user.login)
+    nick = quote(user.nick)
+    email = ''
+    if user.email != None:
+        email = quote(user.email)
+
+    role = quote(str(user.role))
+
+    hashtext = login + nick + email + role + secret
+    hash = hashlib.md5(hashtext).hexdigest()
+    data = quote(login + ':' + nick + ':' + email + ':' + role + ':' + hash)
+
+    return data
+
+class Plugin(ViewPlugin, CookiePlugin):
+    urls = [
+        ('forum', ForumView, {'path': ''}),
+        ('forum/*path', ForumView),
+    ]
+
+    cookies = {'ivleforumcookie': make_forum_cookie}
+
+    media = 'media'

=== renamed directory 'www/media/forum' => 'ivle/webapp/forum/media'
=== added file 'ivle/webapp/forum/template.html'
--- ivle/webapp/forum/template.html	1970-01-01 00:00:00 +0000
+++ ivle/webapp/forum/template.html	2009-02-09 04:50:20 +0000
@@ -0,0 +1,9 @@
+<html xmlns="http://www.w3.org/1999/xhtml"
+      xmlns:py="http://genshi.edgewall.org/">
+  <head>
+    <title>Forum</title>
+  </head>
+  <body>
+    <object class="fullscreen" type="text/html" data="${url}" />
+  </body>
+</html>

